import sklearn.model_selection as model_selection
import pickle as pk

def TestTrainSplit(x, y, testsize, randomstate):
    return model_selection.train_test_split(x, y, test_size=testsize, random_state=randomstate)

def SaveData(x, y, output_file):
    data = {"x": x, "y": y}
    with open(output_file, 'wb') as outfile:
        pk.dump(data, outfile)

def LoadData(input_file):
    with open(input_file, 'rb') as infile:
        data = pk.load(infile)
    return data    


from regrex import linear_model
from regrex import polynomial_model
from regrex import preprocess
from regrex import transform
from regrex import dataset
from regrex import statistics
from regrex import validation
from regrex import log
from regrex import SingleLineFunction


from sklearn.preprocessing import PolynomialFeatures

class Transformer():
    def __init__(self):
        super().__init__()
    def initTransformer(self, degree, includebias):
        self.transformer = PolynomialFeatures(degree=degree, include_bias=includebias)
    def transform(self, x):
        self.transformer.fit(x)    
        x_ = self.transformer.transform(x)
        return x_    


import sys

def Difference(certainval, uncertainval):
    if certainval > uncertainval:
        return certainval - uncertainval
    else:
        return uncertainval - certainval    
def ScoreValidation(modelscore):
    if modelscore > 0.100:
        print("\n\n")
        print("[ERROR] No Logic between Predictor(y) and Response(x)")
        sys.exit()
    else:
        pass    
    


import numpy as np
from sklearn.linear_model import LinearRegression

class Linear():
    def __init__(self):
        super().__init__()
    def initModel(self):
        self.model = LinearRegression()
    def fit(self, x, y):
        self.model.fit(x, y)
    def predict(self, val):
        return self.model.predict(val)    
    def score(self, x, y):
        r_sq = self.model.score(x, y)
        return r_sq
    def coef(self):
        return self.model.coef_
    def intercept(self):
        return self.model.intercept_        



from sklearn.metrics import mean_squared_error
from math import sqrt

def MeanSquaredError(y_predict, y_test):
    return sqrt(mean_squared_error(y_predict, y_test))

def abstract(val):
    return abs(val)

def arraylog(mainstr, arr):
    for obj in arr:
        print(mainstr, obj)

def square(num):
    return sqrt(num)        


from datetime import datetime
from colorama import init 
from termcolor import colored 
init() 
localtime = lambda x: datetime.now().strftime('%H:%M:%S')

def log(strvalue):
    print("[{}] {}".format(localtime(None), str(strvalue)))

def newline():
    print("")

def error(strvalue):
    print("[{}]".format(localtime(None)), colored("[ERROR]", 'white', 'on_red'), strvalue)
